summaryrefslogtreecommitdiffstats
path: root/juk/covermanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/covermanager.h')
-rw-r--r--juk/covermanager.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/juk/covermanager.h b/juk/covermanager.h
index 9a95d991..a935b810 100644
--- a/juk/covermanager.h
+++ b/juk/covermanager.h
@@ -18,8 +18,8 @@
#include <ksharedptr.h>
-#include <qmap.h>
-#include <qdragobject.h>
+#include <tqmap.h>
+#include <tqdragobject.h>
class CoverManagerPrivate;
class QString;
@@ -39,19 +39,19 @@ class QDataStream;
class CoverData : public KShared
{
public:
- QPixmap pixmap() const;
- QPixmap thumbnail() const;
+ TQPixmap pixmap() const;
+ TQPixmap thumbnail() const;
- QString artist;
- QString album;
- QString path;
+ TQString artist;
+ TQString album;
+ TQString path;
unsigned refCount; // Refers to number of tracks using this.
};
typedef KSharedPtr<CoverData> CoverDataPtr;
typedef unsigned long coverKey; ///< Type of the id for a cover.
-typedef QMap<coverKey, CoverDataPtr> CoverDataMap;
+typedef TQMap<coverKey, CoverDataPtr> CoverDataMap;
/**
* This class is used to drag covers in JuK. It adds a special mimetype that
@@ -65,10 +65,10 @@ typedef QMap<coverKey, CoverDataPtr> CoverDataMap;
class CoverDrag : public QDragObject
{
public:
- CoverDrag(coverKey id, QWidget *src);
+ CoverDrag(coverKey id, TQWidget *src);
virtual const char *format(int i) const;
- virtual QByteArray encodedData(const char *mimetype) const;
+ virtual TQByteArray encodedData(const char *mimetype) const;
void setId(coverKey id) { m_id = id; }
@@ -77,8 +77,8 @@ public:
* true is returned only if \p e contains a cover id, even though
* CoverDrag can convert it to an image.
*/
- static bool canDecode(const QMimeSource *e);
- static bool decode(const QMimeSource *e, coverKey &id);
+ static bool canDecode(const TQMimeSource *e);
+ static bool decode(const TQMimeSource *e, coverKey &id);
static const char* mimetype;
@@ -114,7 +114,7 @@ public:
* @return NoMatch if no match could be found, otherwise the id of the
* cover art that matches the given metadata.
*/
- static coverKey idFromMetadata(const QString &artist, const QString &album);
+ static coverKey idFromMetadata(const TQString &artist, const TQString &album);
/**
* Returns the cover art for @p id.
@@ -123,10 +123,10 @@ public:
* @param size The size to return it as. Note that FullSize doesn't
* necessarily mean the pixmap is large, so you may need to
* scale it up.
* @return QPixmap::null if there is no cover art for @p id, otherwise the
* cover art.
*/
- static QPixmap coverFromId(coverKey id, Size size = Thumbnail);
+ static TQPixmap coverFromId(coverKey id, Size size = Thumbnail);
/**
* Returns the cover art for @p ptr. This function is intended for use
@@ -137,7 +137,7 @@ public:
* @param size The size to return it as.
* @see CoverData
*/
- static QPixmap coverFromData(const CoverData &coverData, Size size = Thumbnail);
+ static TQPixmap coverFromData(const CoverData &coverData, Size size = Thumbnail);
/**
* Returns the full suite of information known about the cover given by
@@ -157,7 +157,7 @@ public:
* @param artist The artist of the new cover.
* @param album The album of the new cover.
*/
- static coverKey addCover(const QPixmap &large, const QString &artist = "", const QString &album = "");
+ static coverKey addCover(const TQPixmap &large, const TQString &artist = "", const TQString &album = "");
/**
* Adds the file pointed to by the local path @p path to the database,
@@ -167,7 +167,7 @@ public:
* @param artist The artist of the new cover.
* @param album The album of the new cover.
*/
- static coverKey addCover(const QString &path, const QString &artist = "", const QString &album = "");
+ static coverKey addCover(const TQString &path, const TQString &artist = "", const TQString &album = "");
/**
* Function to determine if @p id matches any covers in the database.
@@ -194,7 +194,7 @@ public:
* @param id The id of the cover to replace.
* @param large The full size cover art for the new cover.
*/
- static bool replaceCover(coverKey id, const QPixmap &large);
+ static bool replaceCover(coverKey id, const TQPixmap &large);
/**
* Saves the current CoverManager information to disk. Changes are not
@@ -224,7 +224,7 @@ public:
/**
* @return A list of all of the id's listed in the database.
*/
- static QValueList<coverKey> keys();
+ static TQValueList<coverKey> keys();
/**
* Associates @p path with the cover identified by @id. No comparison of
@@ -233,7 +233,7 @@ public:
* @param path The absolute file path to the track.
* @param id The identifier of the cover to use with @p path.
*/
- static void setIdForTrack(const QString &path, coverKey id);
+ static void setIdForTrack(const TQString &path, coverKey id);
/**
* Returns the identifier of the cover for the track at @p path.
@@ -242,7 +242,7 @@ public:
* @return NoMatch if @p path doesn't have a cover, otherwise the id of
* its cover.
*/
- static coverKey idForTrack(const QString &path);
+ static coverKey idForTrack(const TQString &path);
/**
* This identifier is used to indicate that no cover was found in the
@@ -254,7 +254,7 @@ public:
static CoverManagerPrivate *m_data;
static CoverManagerPrivate *data();
- static QPixmap createThumbnail(const QPixmap &base);
+ static TQPixmap createThumbnail(const TQPixmap &base);
};
#endif /* JUK_COVERMANAGER_H */
@@ -123,10 +123,10 @@ public:
* necessarily mean the pixmap is large, so you may need to
* scale it up.
- * @return QPixmap::null if there is no cover art for @p id, otherwise the
+ * @return TQPixmap::null if there is no cover art for @p id, otherwise the
* cover art.
*/